"use strict";

exports.__esModule = true;
exports.default = void 0;

var _utils = require("../common/utils");

var _constants = require("../common/constants");

var SpanBase = function () {
  function SpanBase(name, type, options) {
    if (options === void 0) {
      options = {};
    }

    if (!name) {
      name = _constants.NAME_UNKNOWN;
    }

    if (!type) {
      type = _constants.TYPE_CUSTOM;
    }

    this.name = name;
    this.type = type;
    this.options = options;
    this.id = options.id || (0, _utils.generateRandomId)(16);
    this.traceId = options.traceId;
    this.sampled = options.sampled;
    this.timestamp = options.timestamp;
    this._start = (0, _utils.getTime)(options.startTime);
    this._end = undefined;
    this.ended = false;
    this.onEnd = options.onEnd;
  }

  var _proto = SpanBase.prototype;

  _proto.ensureContext = function ensureContext() {
    if (!this.context) {
      this.context = {};
    }
  };

  _proto.addTags = function addTags(tags) {
    console.warn('addTags deprecated, please use addLabels');
    this.addLabels(tags);
  };

  _proto.addLabels = function addLabels(tags) {
    this.ensureContext();
    var ctx = this.context;

    if (!ctx.tags) {
      ctx.tags = {};
    }

    var keys = Object.keys(tags);
    keys.forEach(function (k) {
      return (0, _utils.setLabel)(k, tags[k], ctx.tags);
    });
  };

  _proto.addContext = function addContext(context) {
    if (!context) return;
    this.ensureContext();
    (0, _utils.merge)(this.context, context);
  };

  _proto.end = function end(endTime) {
    if (this.ended) {
      return;
    }

    this.ended = true;
    this._end = (0, _utils.getTime)(endTime);
    this.callOnEnd();
  };

  _proto.callOnEnd = function callOnEnd() {
    if (typeof this.onEnd === 'function') {
      this.onEnd(this);
    }
  };

  _proto.duration = function duration() {
    return (0, _utils.getDuration)(this._start, this._end);
  };

  return SpanBase;
}();

var _default = SpanBase;
exports.default = _default;