"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var spec_factory_1 = require("../state/spec_factory");
var light_theme_1 = require("../utils/themes/light_theme");
var chart_types_1 = require("../chart_types");
var commons_1 = require("../utils/commons");
exports.PointerEventType = Object.freeze({
    Over: 'Over',
    Out: 'Out',
});
exports.TooltipType = Object.freeze({
    VerticalCursor: 'vertical',
    Crosshairs: 'cross',
    Follow: 'follow',
    None: 'none',
});
exports.DEFAULT_TOOLTIP_TYPE = exports.TooltipType.VerticalCursor;
exports.DEFAULT_TOOLTIP_SNAP = true;
exports.SpecTypes = Object.freeze({
    Series: 'series',
    Axis: 'axis',
    Annotation: 'annotation',
    Settings: 'settings',
});
exports.DEFAULT_SETTINGS_SPEC = {
    id: '__global__settings___',
    chartType: chart_types_1.ChartTypes.Global,
    specType: exports.SpecTypes.Settings,
    rendering: 'canvas',
    rotation: 0,
    animateData: true,
    showLegend: false,
    resizeDebounce: 10,
    debug: false,
    tooltip: {
        type: exports.DEFAULT_TOOLTIP_TYPE,
        snap: exports.DEFAULT_TOOLTIP_SNAP,
    },
    legendPosition: commons_1.Position.Right,
    showLegendExtra: false,
    hideDuplicateAxes: false,
    theme: light_theme_1.LIGHT_THEME,
};
exports.Settings = spec_factory_1.getConnect()(spec_factory_1.specComponentFactory(exports.DEFAULT_SETTINGS_SPEC));
function isPointerOutEvent(event) {
    return event !== null && event !== undefined && event.type === exports.PointerEventType.Out;
}
exports.isPointerOutEvent = isPointerOutEvent;
function isPointerOverEvent(event) {
    return event !== null && event !== undefined && event.type === exports.PointerEventType.Over;
}
exports.isPointerOverEvent = isPointerOverEvent;
function isTooltipProps(config) {
    return typeof config === 'object';
}
exports.isTooltipProps = isTooltipProps;
function isTooltipType(config) {
    return typeof config === 'string';
}
exports.isTooltipType = isTooltipType;
function isCrosshairTooltipType(type) {
    return type === exports.TooltipType.VerticalCursor || type === exports.TooltipType.Crosshairs;
}
exports.isCrosshairTooltipType = isCrosshairTooltipType;
function isFollowTooltipType(type) {
    return type === exports.TooltipType.Follow;
}
exports.isFollowTooltipType = isFollowTooltipType;
function getTooltipType(settings) {
    var tooltip = settings.tooltip;
    if (tooltip === undefined || tooltip === null) {
        return undefined;
    }
    if (isTooltipType(tooltip)) {
        return tooltip;
    }
    if (isTooltipProps(tooltip)) {
        return tooltip.type || undefined;
    }
    return undefined;
}
exports.getTooltipType = getTooltipType;
//# sourceMappingURL=settings.js.map